#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-BRgG1IFKYOaC6CrrdgtZAm
key:                  deriving-aeson-0.2.10-BRgG1IFKYOaC6CrrdgtZAm
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  f73b43b5de67e7bf35f9432455f9b081
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-BRgG1IFKYOaC6CrrdgtZAm
depends:              aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

